@@ -14,15 +14,9 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+
 package org.apache.doris.flink.catalog;
 
-import org.apache.commons.compress.utils.Lists;
-import org.apache.doris.flink.catalog.doris.DataModel;
-import org.apache.doris.flink.catalog.doris.DorisSystem;
-import org.apache.doris.flink.catalog.doris.FieldSchema;
-import org.apache.doris.flink.catalog.doris.TableSchema;
-import org.apache.doris.flink.cfg.DorisConnectionOptions;
-import org.apache.doris.flink.table.DorisDynamicTableFactory;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.table.api.Schema;
 import org.apache.flink.table.catalog.AbstractCatalog;
@@ -54,6 +48,14 @@ import org.apache.flink.table.factories.Factory;
 import org.apache.flink.table.types.DataType;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.StringUtils;
+
+import org.apache.commons.compress.utils.Lists;
+import org.apache.doris.flink.catalog.doris.DataModel;
+import org.apache.doris.flink.catalog.doris.DorisSystem;
+import org.apache.doris.flink.catalog.doris.FieldSchema;
+import org.apache.doris.flink.catalog.doris.TableSchema;
+import org.apache.doris.flink.cfg.DorisConnectionOptions;
+import org.apache.doris.flink.table.DorisDynamicTableFactory;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -61,6 +63,7 @@ import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
+import java.sql.ResultSetMetaData;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -82,9 +85,7 @@ import static org.apache.flink.table.factories.FactoryUtil.CONNECTOR;
 import static org.apache.flink.util.Preconditions.checkArgument;
 import static org.apache.flink.util.Preconditions.checkNotNull;
 
-/**
- * catalog for flink
- */
+/** catalog for flink. */
 public class DorisCatalog extends AbstractCatalog {
 
     private static final Logger LOG = LoggerFactory.getLogger(DorisCatalog.class);
@@ -147,12 +148,12 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public void createDatabase(String name, CatalogDatabase database, boolean ignoreIfExists)
             throws DatabaseAlreadyExistException, CatalogException {
-        if(databaseExists(name)){
-            if(ignoreIfExists){
+        if (databaseExists(name)) {
+            if (ignoreIfExists) {
                 return;
             }
             throw new DatabaseAlreadyExistException(getName(), name);
-        }else {
+        } else {
             dorisSystem.createDatabase(name);
         }
     }
@@ -160,7 +161,7 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public void dropDatabase(String name, boolean ignoreIfNotExists, boolean cascade)
             throws DatabaseNotEmptyException, CatalogException, DatabaseNotExistException {
-        if(!databaseExists(name)){
+        if (!databaseExists(name)) {
             if (ignoreIfNotExists) {
                 return;
             }
@@ -168,7 +169,7 @@ public class DorisCatalog extends AbstractCatalog {
         }
 
         if (!cascade && listTables(name).size() > 0) {
-            throw new DatabaseNotEmptyException(getName(),name);
+            throw new DatabaseNotEmptyException(getName(), name);
         }
         dorisSystem.dropDatabase(name);
     }
@@ -185,7 +186,8 @@ public class DorisCatalog extends AbstractCatalog {
     public List<String> listTables(String databaseName)
             throws DatabaseNotExistException, CatalogException {
         Preconditions.checkState(
-                org.apache.commons.lang3.StringUtils.isNotBlank(databaseName), "Database name must not be blank.");
+                org.apache.commons.lang3.StringUtils.isNotBlank(databaseName),
+                "Database name must not be blank.");
         if (!databaseExists(databaseName)) {
             throw new DatabaseNotExistException(getName(), databaseName);
         }
@@ -220,24 +222,38 @@ public class DorisCatalog extends AbstractCatalog {
         props.put(PASSWORD.key(), connectionOptions.getPassword());
         props.put(TABLE_IDENTIFIER.key(), databaseName + "." + tableName);
 
-        String labelPrefix = props.getOrDefault(SINK_LABEL_PREFIX.key(),"");
-        props.put(SINK_LABEL_PREFIX.key(), String.join("_",labelPrefix,databaseName,tableName));
-        //remove catalog option
+        String labelPrefix = props.getOrDefault(SINK_LABEL_PREFIX.key(), "");
+        props.put(SINK_LABEL_PREFIX.key(), String.join("_", labelPrefix, databaseName, tableName));
+        // remove catalog option
         props.remove(DEFAULT_DATABASE.key());
-        return CatalogTable.of(createTableSchema(databaseName, tableName), null, Lists.newArrayList(), props);
-
+        return CatalogTable.of(
+                createTableSchema(databaseName, tableName), null, Lists.newArrayList(), props);
     }
 
     @VisibleForTesting
     protected String queryFenodes() {
-        try (Connection conn = DriverManager.getConnection(connectionOptions.getJdbcUrl(),
-                connectionOptions.getUsername(),
-                connectionOptions.getPassword())) {
+        try (Connection conn =
+                DriverManager.getConnection(
+                        connectionOptions.getJdbcUrl(),
+                        connectionOptions.getUsername(),
+                        connectionOptions.getPassword())) {
             StringJoiner fenodes = new StringJoiner(",");
             PreparedStatement ps = conn.prepareStatement("SHOW FRONTENDS");
             ResultSet resultSet = ps.executeQuery();
+
+            // find target ip column name, Version 1.2 is IP, version 2.x is Host
+            String field = "";
+            ResultSetMetaData metaData = resultSet.getMetaData();
+            for (int i = 1; i <= metaData.getColumnCount(); i++) {
+                String columnName = metaData.getColumnName(i);
+                if (columnName.equalsIgnoreCase("IP") || columnName.equalsIgnoreCase("Host")) {
+                    field = columnName;
+                    break;
+                }
+            }
+
             while (resultSet.next()) {
-                String ip = resultSet.getString("IP");
+                String ip = resultSet.getString(field);
                 String port = resultSet.getString("HttpPort");
                 fenodes.add(ip + ":" + port);
             }
@@ -248,12 +264,16 @@ public class DorisCatalog extends AbstractCatalog {
     }
 
     private Schema createTableSchema(String databaseName, String tableName) {
-        try (Connection conn = DriverManager.getConnection(connectionOptions.getJdbcUrl(),
-                connectionOptions.getUsername(),
-                connectionOptions.getPassword())) {
+        try (Connection conn =
+                DriverManager.getConnection(
+                        connectionOptions.getJdbcUrl(),
+                        connectionOptions.getUsername(),
+                        connectionOptions.getPassword())) {
             PreparedStatement ps =
                     conn.prepareStatement(
-                            String.format("SELECT COLUMN_NAME,DATA_TYPE,COLUMN_SIZE,DECIMAL_DIGITS FROM `information_schema`.`COLUMNS` WHERE `TABLE_SCHEMA`= '%s' AND `TABLE_NAME`= '%s'", databaseName, tableName));
+                            String.format(
+                                    "SELECT COLUMN_NAME,DATA_TYPE,COLUMN_SIZE,DECIMAL_DIGITS FROM `information_schema`.`COLUMNS` WHERE `TABLE_SCHEMA`= '%s' AND `TABLE_NAME`= '%s'",
+                                    databaseName, tableName));
 
             List<String> columnNames = new ArrayList<>();
             List<DataType> columnTypes = new ArrayList<>();
@@ -264,7 +284,9 @@ public class DorisCatalog extends AbstractCatalog {
                 long columnSize = resultSet.getLong("COLUMN_SIZE");
                 long columnDigit = resultSet.getLong("DECIMAL_DIGITS");
 
-                DataType flinkType = DorisTypeMapper.toFlinkType(columnName, columnType, (int) columnSize, (int) columnDigit);
+                DataType flinkType =
+                        DorisTypeMapper.toFlinkType(
+                                columnName, columnType, (int) columnSize, (int) columnDigit);
                 columnNames.add(columnName);
                 columnTypes.add(flinkType);
             }
@@ -273,7 +295,10 @@ public class DorisCatalog extends AbstractCatalog {
             return tableSchema;
         } catch (Exception e) {
             throw new CatalogException(
-                    String.format("Failed getting catalog %s database %s table %s", getName(), databaseName, tableName), e);
+                    String.format(
+                            "Failed getting catalog %s database %s table %s",
+                            getName(), databaseName, tableName),
+                    e);
         }
     }
 
@@ -290,14 +315,15 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public void dropTable(ObjectPath tablePath, boolean ignoreIfNotExists)
             throws TableNotExistException, CatalogException {
-        if(!tableExists(tablePath)){
-            if(ignoreIfNotExists){
+        if (!tableExists(tablePath)) {
+            if (ignoreIfNotExists) {
                 return;
             }
             throw new TableNotExistException(getName(), tablePath);
         }
 
-        dorisSystem.dropTable(String.format("%s.%s", tablePath.getDatabaseName(), tablePath.getObjectName()));
+        dorisSystem.dropTable(
+                String.format("%s.%s", tablePath.getDatabaseName(), tablePath.getObjectName()));
     }
 
     @Override
@@ -312,11 +338,11 @@ public class DorisCatalog extends AbstractCatalog {
         checkNotNull(tablePath, "tablePath cannot be null");
         checkNotNull(table, "table cannot be null");
 
-        if(!databaseExists(tablePath.getDatabaseName())) {
+        if (!databaseExists(tablePath.getDatabaseName())) {
             throw new DatabaseNotExistException(getName(), tablePath.getDatabaseName());
         }
-        if(tableExists(tablePath)){
-            if(ignoreIfExists){
+        if (tableExists(tablePath)) {
+            if (ignoreIfExists) {
                 return;
             }
             throw new TableAlreadyExistException(getName(), tablePath);
@@ -341,22 +367,22 @@ public class DorisCatalog extends AbstractCatalog {
         dorisSystem.createTable(schema);
     }
 
-    public List<String> getCreateDorisKeys(org.apache.flink.table.api.TableSchema schema){
-        Preconditions.checkState(schema.getPrimaryKey().isPresent(),"primary key cannot be null");
+    public List<String> getCreateDorisKeys(org.apache.flink.table.api.TableSchema schema) {
+        Preconditions.checkState(schema.getPrimaryKey().isPresent(), "primary key cannot be null");
         return schema.getPrimaryKey().get().getColumns();
     }
 
-    public Map<String, FieldSchema> getCreateDorisColumns(org.apache.flink.table.api.TableSchema schema){
+    public Map<String, FieldSchema> getCreateDorisColumns(
+            org.apache.flink.table.api.TableSchema schema) {
         String[] fieldNames = schema.getFieldNames();
         DataType[] fieldTypes = schema.getFieldDataTypes();
 
         Map<String, FieldSchema> fields = new LinkedHashMap<>();
         for (int i = 0; i < fieldNames.length; i++) {
-            fields.put(fieldNames[i],
+            fields.put(
+                    fieldNames[i],
                     new FieldSchema(
-                            fieldNames[i],
-                            DorisTypeMapper.toDorisType(fieldTypes[i]),
-                            null));
+                            fieldNames[i], DorisTypeMapper.toDorisType(fieldTypes[i]), null));
         }
         return fields;
     }
@@ -380,7 +406,7 @@ public class DorisCatalog extends AbstractCatalog {
     public List<CatalogPartitionSpec> listPartitions(
             ObjectPath tablePath, CatalogPartitionSpec partitionSpec)
             throws TableNotExistException, TableNotPartitionedException,
-            PartitionSpecInvalidException, CatalogException {
+                    PartitionSpecInvalidException, CatalogException {
         return Collections.emptyList();
     }
 
@@ -410,8 +436,8 @@ public class DorisCatalog extends AbstractCatalog {
             CatalogPartition partition,
             boolean ignoreIfExists)
             throws TableNotExistException, TableNotPartitionedException,
-            PartitionSpecInvalidException, PartitionAlreadyExistsException,
-            CatalogException {
+                    PartitionSpecInvalidException, PartitionAlreadyExistsException,
+                    CatalogException {
         throw new UnsupportedOperationException();
     }
 
