@@ -14,8 +14,8 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
-package org.apache.doris.flink.deserialization;
 
+package org.apache.doris.flink.deserialization;
 
 import org.apache.flink.api.common.typeinfo.TypeHint;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
@@ -27,8 +27,7 @@ public class SimpleListDeserializationSchema implements DorisDeserializationSche
 
     @Override
     public TypeInformation<List<?>> getProducedType() {
-        return TypeInformation.of(new TypeHint<List<?>>() {
-        });
+        return TypeInformation.of(new TypeHint<List<?>>() {});
     }
 
     @Override
