@@ -17,6 +17,13 @@
 
 package org.apache.doris.flink.sink.writer;
 
+import org.apache.flink.annotation.VisibleForTesting;
+import org.apache.flink.api.connector.sink2.Sink;
+import org.apache.flink.api.connector.sink2.StatefulSink;
+import org.apache.flink.api.connector.sink2.TwoPhaseCommittingSink;
+import org.apache.flink.runtime.checkpoint.CheckpointIDCounter;
+import org.apache.flink.util.concurrent.ExecutorThreadFactory;
+
 import org.apache.commons.lang3.StringUtils;
 import org.apache.doris.flink.cfg.DorisExecutionOptions;
 import org.apache.doris.flink.cfg.DorisOptions;
@@ -29,12 +36,6 @@ import org.apache.doris.flink.sink.DorisCommittable;
 import org.apache.doris.flink.sink.HttpUtil;
 import org.apache.doris.flink.sink.writer.serializer.DorisRecord;
 import org.apache.doris.flink.sink.writer.serializer.DorisRecordSerializer;
-import org.apache.flink.annotation.VisibleForTesting;
-import org.apache.flink.api.connector.sink2.Sink;
-import org.apache.flink.api.connector.sink2.StatefulSink;
-import org.apache.flink.api.connector.sink2.TwoPhaseCommittingSink;
-import org.apache.flink.runtime.checkpoint.CheckpointIDCounter;
-import org.apache.flink.util.concurrent.ExecutorThreadFactory;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -55,16 +56,19 @@ import static org.apache.doris.flink.sink.LoadStatus.SUCCESS;
 
 /**
  * Doris Writer will load data to doris.
+ *
  * @param <IN>
  */
-public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, DorisWriterState>,
-        TwoPhaseCommittingSink.PrecommittingSinkWriter<IN, DorisCommittable> {
+public class DorisWriter<IN>
+        implements StatefulSink.StatefulSinkWriter<IN, DorisWriterState>,
+                TwoPhaseCommittingSink.PrecommittingSinkWriter<IN, DorisCommittable> {
     private static final Logger LOG = LoggerFactory.getLogger(DorisWriter.class);
-    private static final List<String> DORIS_SUCCESS_STATUS = new ArrayList<>(Arrays.asList(SUCCESS, PUBLISH_TIMEOUT));
+    private static final List<String> DORIS_SUCCESS_STATUS =
+            new ArrayList<>(Arrays.asList(SUCCESS, PUBLISH_TIMEOUT));
     private final long lastCheckpointId;
     private long curCheckpointId;
     private Map<String, DorisStreamLoad> dorisStreamLoadMap = new ConcurrentHashMap<>();
-    private Map<String, LabelGenerator> labelGeneratorMap = new ConcurrentHashMap<>();;
+    private Map<String, LabelGenerator> labelGeneratorMap = new ConcurrentHashMap<>();
     volatile boolean globalLoading;
     private Map<String, Boolean> loadingMap = new ConcurrentHashMap<>();
     private final DorisOptions dorisOptions;
@@ -79,12 +83,13 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
     private transient volatile Exception loadException = null;
     private BackendUtil backendUtil;
 
-    public DorisWriter(Sink.InitContext initContext,
-                       Collection<DorisWriterState> state,
-                       DorisRecordSerializer<IN> serializer,
-                       DorisOptions dorisOptions,
-                       DorisReadOptions dorisReadOptions,
-                       DorisExecutionOptions executionOptions) {
+    public DorisWriter(
+            Sink.InitContext initContext,
+            Collection<DorisWriterState> state,
+            DorisRecordSerializer<IN> serializer,
+            DorisOptions dorisOptions,
+            DorisReadOptions dorisReadOptions,
+            DorisExecutionOptions executionOptions) {
         this.lastCheckpointId =
                 initContext
                         .getRestoredCheckpointId()
@@ -94,7 +99,8 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
         LOG.info("labelPrefix " + executionOptions.getLabelPrefix());
         this.labelPrefix = executionOptions.getLabelPrefix();
         this.subtaskId = initContext.getSubtaskId();
-        this.scheduledExecutorService = new ScheduledThreadPoolExecutor(1, new ExecutorThreadFactory("stream-load-check"));
+        this.scheduledExecutorService =
+                new ScheduledThreadPoolExecutor(1, new ExecutorThreadFactory("stream-load-check"));
         this.serializer = serializer;
         this.dorisOptions = dorisOptions;
         this.dorisReadOptions = dorisReadOptions;
@@ -103,12 +109,13 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
         this.globalLoading = false;
 
         initializeLoad(state);
+        serializer.initial();
     }
 
     public void initializeLoad(Collection<DorisWriterState> state) {
         this.backendUtil = BackendUtil.getInstance(dorisOptions, dorisReadOptions, LOG);
         try {
-            if(executionOptions.enabled2PC()) {
+            if (executionOptions.enabled2PC()) {
                 abortLingeringTransactions(state);
             }
         } catch (Exception e) {
@@ -117,31 +124,42 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
         }
         // get main work thread.
         executorThread = Thread.currentThread();
-        // when uploading data in streaming mode, we need to regularly detect whether there are exceptions.
-        scheduledExecutorService.scheduleWithFixedDelay(this::checkDone, 200, intervalTime, TimeUnit.MILLISECONDS);
+        // when uploading data in streaming mode, we need to regularly detect whether there are
+        // exceptions.
+        scheduledExecutorService.scheduleWithFixedDelay(
+                this::checkDone, 200, intervalTime, TimeUnit.MILLISECONDS);
     }
 
-    private void abortLingeringTransactions(Collection<DorisWriterState> recoveredStates) throws Exception {
+    private void abortLingeringTransactions(Collection<DorisWriterState> recoveredStates)
+            throws Exception {
         List<String> alreadyAborts = new ArrayList<>();
-        //abort label in state
-         for(DorisWriterState state : recoveredStates){
-             // Todo: When the sink parallelism is reduced,
-             //  the txn of the redundant task before aborting is also needed.
-             if(!state.getLabelPrefix().equals(labelPrefix)){
-                 LOG.warn("Label prefix from previous execution {} has changed to {}.", state.getLabelPrefix(), executionOptions.getLabelPrefix());
-             }
-             String key = state.getDatabase() + "." + state.getTable();
-             DorisStreamLoad streamLoader = getStreamLoader(key);
-             streamLoader.abortPreCommit(state.getLabelPrefix(), curCheckpointId);
-             alreadyAborts.add(state.getLabelPrefix());
+        // abort label in state
+        for (DorisWriterState state : recoveredStates) {
+            // Todo: When the sink parallelism is reduced,
+            //  the txn of the redundant task before aborting is also needed.
+            if (!state.getLabelPrefix().equals(labelPrefix)) {
+                LOG.warn(
+                        "Label prefix from previous execution {} has changed to {}.",
+                        state.getLabelPrefix(),
+                        executionOptions.getLabelPrefix());
+            }
+            if (state.getDatabase() == null || state.getTable() == null) {
+                LOG.warn(
+                        "Transactions cannot be aborted when restore because the last used flink-doris-connector version less than 1.5.0.");
+                continue;
+            }
+            String key = state.getDatabase() + "." + state.getTable();
+            DorisStreamLoad streamLoader = getStreamLoader(key);
+            streamLoader.abortPreCommit(state.getLabelPrefix(), curCheckpointId);
+            alreadyAborts.add(state.getLabelPrefix());
         }
 
         // TODO: In a multi-table scenario, if do not restore from checkpoint,
         //  when modify labelPrefix at startup, we cannot abort the previous label.
-        if(!alreadyAborts.contains(labelPrefix)
+        if (!alreadyAborts.contains(labelPrefix)
                 && StringUtils.isNotEmpty(dorisOptions.getTableIdentifier())
-                && StringUtils.isNotEmpty(labelPrefix)){
-            //abort current labelPrefix
+                && StringUtils.isNotEmpty(labelPrefix)) {
+            // abort current labelPrefix
             DorisStreamLoad streamLoader = getStreamLoader(dorisOptions.getTableIdentifier());
             streamLoader.abortPreCommit(labelPrefix, curCheckpointId);
         }
@@ -150,20 +168,29 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
     @Override
     public void write(IN in, Context context) throws IOException {
         checkLoadException();
-        String tableKey = dorisOptions.getTableIdentifier();
+        writeOneDorisRecord(serializer.serialize(in));
+    }
 
-        DorisRecord record = serializer.serialize(in);
-        if(record == null || record.getRow() == null){
-            //ddl or value is null
+    @Override
+    public void flush(boolean endOfInput) throws IOException, InterruptedException {
+        writeOneDorisRecord(serializer.flush());
+    }
+
+    public void writeOneDorisRecord(DorisRecord record) throws IOException {
+
+        if (record == null || record.getRow() == null) {
+            // ddl or value is null
             return;
         }
-        //multi table load
-        if(record.getTableIdentifier() != null){
+
+        // multi table load
+        String tableKey = dorisOptions.getTableIdentifier();
+        if (record.getTableIdentifier() != null) {
             tableKey = record.getTableIdentifier();
         }
 
         DorisStreamLoad streamLoader = getStreamLoader(tableKey);
-        if(!loadingMap.containsKey(tableKey)) {
+        if (!loadingMap.containsKey(tableKey)) {
             // start stream load only when there has data
             LabelGenerator labelGenerator = getLabelGenerator(tableKey);
             String currentLabel = labelGenerator.generateTableLabel(curCheckpointId);
@@ -174,15 +201,10 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
         streamLoader.writeRecord(record.getRow());
     }
 
-    @Override
-    public void flush(boolean flush) throws IOException, InterruptedException {
-        //No action is triggered, everything is in the precommit method
-    }
-
     @Override
     public Collection<DorisCommittable> prepareCommit() throws IOException, InterruptedException {
         // Verify whether data is written during a checkpoint
-        if(!globalLoading && loadingMap.values().stream().noneMatch(Boolean::booleanValue)){
+        if (!globalLoading && loadingMap.values().stream().noneMatch(Boolean::booleanValue)) {
             return Collections.emptyList();
         }
         // disable exception checker before stop load.
@@ -190,9 +212,9 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
 
         // submit stream load http request
         List<DorisCommittable> committableList = new ArrayList<>();
-        for(Map.Entry<String, DorisStreamLoad> streamLoader : dorisStreamLoadMap.entrySet()){
+        for (Map.Entry<String, DorisStreamLoad> streamLoader : dorisStreamLoadMap.entrySet()) {
             String tableIdentifier = streamLoader.getKey();
-            if(!loadingMap.getOrDefault(tableIdentifier, false)){
+            if (!loadingMap.getOrDefault(tableIdentifier, false)) {
                 LOG.debug("skip table {}, no data need to load.", tableIdentifier);
                 continue;
             }
@@ -201,12 +223,19 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
             String currentLabel = labelGenerator.generateTableLabel(curCheckpointId);
             RespContent respContent = dorisStreamLoad.stopLoad(currentLabel);
             if (!DORIS_SUCCESS_STATUS.contains(respContent.getStatus())) {
-                String errMsg = String.format("tabel {} stream load error: %s, see more in %s", tableIdentifier, respContent.getMessage(), respContent.getErrorURL());
+                String errMsg =
+                        String.format(
+                                "tabel {} stream load error: %s, see more in %s",
+                                tableIdentifier,
+                                respContent.getMessage(),
+                                respContent.getErrorURL());
                 throw new DorisRuntimeException(errMsg);
             }
-            if(executionOptions.enabled2PC()){
+            if (executionOptions.enabled2PC()) {
                 long txnId = respContent.getTxnId();
-                committableList.add(new DorisCommittable(dorisStreamLoad.getHostPort(), dorisStreamLoad.getDb(), txnId));
+                committableList.add(
+                        new DorisCommittable(
+                                dorisStreamLoad.getHostPort(), dorisStreamLoad.getDb(), txnId));
             }
         }
         // clean loadingMap
@@ -217,40 +246,51 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
     @Override
     public List<DorisWriterState> snapshotState(long checkpointId) throws IOException {
         List<DorisWriterState> writerStates = new ArrayList<>();
-        for(DorisStreamLoad dorisStreamLoad : dorisStreamLoadMap.values()){
-            //Dynamic refresh backend
+        for (DorisStreamLoad dorisStreamLoad : dorisStreamLoadMap.values()) {
+            // Dynamic refresh backend
             dorisStreamLoad.setHostPort(backendUtil.getAvailableBackend());
-            DorisWriterState writerState = new DorisWriterState(labelPrefix, dorisStreamLoad.getDb(), dorisStreamLoad.getTable(), subtaskId);
+            DorisWriterState writerState =
+                    new DorisWriterState(
+                            labelPrefix,
+                            dorisStreamLoad.getDb(),
+                            dorisStreamLoad.getTable(),
+                            subtaskId);
             writerStates.add(writerState);
         }
         this.curCheckpointId = checkpointId + 1;
         return writerStates;
     }
 
-    private LabelGenerator getLabelGenerator(String tableKey){
-        return labelGeneratorMap.computeIfAbsent(tableKey, v-> new LabelGenerator(labelPrefix, executionOptions.enabled2PC(), tableKey, subtaskId));
+    private LabelGenerator getLabelGenerator(String tableKey) {
+        return labelGeneratorMap.computeIfAbsent(
+                tableKey,
+                v ->
+                        new LabelGenerator(
+                                labelPrefix, executionOptions.enabled2PC(), tableKey, subtaskId));
     }
 
-    private DorisStreamLoad getStreamLoader(String tableKey){
+    private DorisStreamLoad getStreamLoader(String tableKey) {
         LabelGenerator labelGenerator = getLabelGenerator(tableKey);
         dorisOptions.setTableIdentifier(tableKey);
-        return dorisStreamLoadMap.computeIfAbsent(tableKey, v -> new DorisStreamLoad(backendUtil.getAvailableBackend(),
-                dorisOptions,
-                executionOptions,
-                labelGenerator,
-                new HttpUtil().getHttpClient()));
+        return dorisStreamLoadMap.computeIfAbsent(
+                tableKey,
+                v ->
+                        new DorisStreamLoad(
+                                backendUtil.getAvailableBackend(),
+                                dorisOptions,
+                                executionOptions,
+                                labelGenerator,
+                                new HttpUtil().getHttpClient()));
     }
 
-    /**
-     * Check the streamload http request regularly
-     */
+    /** Check the streamload http request regularly. */
     private void checkDone() {
-        for(Map.Entry<String, DorisStreamLoad> streamLoadMap : dorisStreamLoadMap.entrySet()){
+        for (Map.Entry<String, DorisStreamLoad> streamLoadMap : dorisStreamLoadMap.entrySet()) {
             checkAllDone(streamLoadMap.getKey(), streamLoadMap.getValue());
         }
     }
 
-    private void checkAllDone(String tableIdentifier, DorisStreamLoad dorisStreamLoad){
+    private void checkAllDone(String tableIdentifier, DorisStreamLoad dorisStreamLoad) {
         // the load future is done and checked in prepareCommit().
         // this will check error while loading.
         LOG.debug("start timer checker, interval {} ms", intervalTime);
@@ -274,23 +314,32 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
                             dorisStreamLoad.abortPreCommit(labelPrefix, curCheckpointId);
                         }
                         // start a new txn(stream load)
-                        LOG.info("getting exception, breakpoint resume for checkpoint ID: {}, table {}", curCheckpointId, tableIdentifier);
+                        LOG.info(
+                                "getting exception, breakpoint resume for checkpoint ID: {}, table {}",
+                                curCheckpointId,
+                                tableIdentifier);
                         LabelGenerator labelGenerator = getLabelGenerator(tableIdentifier);
-                        dorisStreamLoad.startLoad(labelGenerator.generateTableLabel(curCheckpointId), true);
+                        dorisStreamLoad.startLoad(
+                                labelGenerator.generateTableLabel(curCheckpointId), true);
                     } catch (Exception e) {
                         throw new DorisRuntimeException(e);
                     }
                 } else {
                     String errorMsg;
                     try {
-                        RespContent content = dorisStreamLoad.handlePreCommitResponse(dorisStreamLoad.getPendingLoadFuture().get());
+                        RespContent content =
+                                dorisStreamLoad.handlePreCommitResponse(
+                                        dorisStreamLoad.getPendingLoadFuture().get());
                         errorMsg = content.getMessage();
                     } catch (Exception e) {
                         errorMsg = e.getMessage();
                     }
 
                     loadException = new StreamLoadException(errorMsg);
-                    LOG.error("table {} stream load finished unexpectedly, interrupt worker thread! {}", tableIdentifier, errorMsg);
+                    LOG.error(
+                            "table {} stream load finished unexpectedly, interrupt worker thread! {}",
+                            tableIdentifier,
+                            errorMsg);
                     // set the executor thread interrupted in case blocking in write data.
                     executorThread.interrupt();
                 }
@@ -321,10 +370,10 @@ public class DorisWriter<IN> implements StatefulSink.StatefulSinkWriter<IN, Dori
             scheduledExecutorService.shutdownNow();
         }
         if (dorisStreamLoadMap != null && !dorisStreamLoadMap.isEmpty()) {
-            for(DorisStreamLoad dorisStreamLoad : dorisStreamLoadMap.values()){
+            for (DorisStreamLoad dorisStreamLoad : dorisStreamLoadMap.values()) {
                 dorisStreamLoad.close();
             }
         }
+        serializer.close();
     }
-
 }
