@@ -14,26 +14,25 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+
 package org.apache.doris.flink.tools.cdc;
 
+import org.apache.flink.api.java.utils.MultipleParameterTool;
+import org.apache.flink.configuration.Configuration;
+import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
+import org.apache.flink.util.StringUtils;
 
 import org.apache.doris.flink.tools.cdc.mysql.MysqlDatabaseSync;
 import org.apache.doris.flink.tools.cdc.oracle.OracleDatabaseSync;
 import org.apache.doris.flink.tools.cdc.postgres.PostgresDatabaseSync;
 import org.apache.doris.flink.tools.cdc.sqlserver.SqlServerDatabaseSync;
-import org.apache.flink.api.java.utils.MultipleParameterTool;
-import org.apache.flink.configuration.Configuration;
-import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
-import org.apache.flink.util.StringUtils;
 
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-/**
- * cdc sync tools
- */
+/** cdc sync tools. */
 public class CdcTools {
     private static final String MYSQL_SYNC_DATABASE = "mysql-sync-database";
     private static final String ORACLE_SYNC_DATABASE = "oracle-sync-database";
@@ -96,7 +95,12 @@ public class CdcTools {
         syncDatabase(params, databaseSync, postgresConfig, "SqlServer");
     }
 
-    private static void syncDatabase(MultipleParameterTool params, DatabaseSync databaseSync, Configuration config, String type) throws Exception {
+    private static void syncDatabase(
+            MultipleParameterTool params,
+            DatabaseSync databaseSync,
+            Configuration config,
+            String type)
+            throws Exception {
         String jobName = params.get("job-name");
         String database = params.get("database");
         String tablePrefix = params.get("table-prefix");
@@ -115,7 +119,8 @@ public class CdcTools {
         Configuration sinkConfig = Configuration.fromMap(sinkMap);
 
         StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        databaseSync.setEnv(env)
+        databaseSync
+                .setEnv(env)
                 .setDatabase(database)
                 .setConfig(config)
                 .setTablePrefix(tablePrefix)
@@ -132,8 +137,11 @@ public class CdcTools {
                 .setSingleSink(singleSink)
                 .create();
         databaseSync.build();
-        if(StringUtils.isNullOrWhitespaceOnly(jobName)){
-            jobName = String.format("%s-Doris Sync Database: %s", type, config.getString("database-name","db"));
+        if (StringUtils.isNullOrWhitespaceOnly(jobName)) {
+            jobName =
+                    String.format(
+                            "%s-Doris Sync Database: %s",
+                            type, config.getString("database-name", "db"));
         }
         env.execute(jobName);
     }
@@ -149,15 +157,14 @@ public class CdcTools {
             if (kv.length == 2) {
                 map.put(kv[0], kv[1]);
                 continue;
-            }else if(kv.length == 1 && EMPTY_KEYS.contains(kv[0])){
+            } else if (kv.length == 1 && EMPTY_KEYS.contains(kv[0])) {
                 map.put(kv[0], "");
                 continue;
             }
 
-            System.err.println(
-                    "Invalid " + key + " " + param + ".\n");
+            System.err.println("Invalid " + key + " " + param + ".\n");
             return null;
         }
         return map;
     }
-}
\ No newline at end of file
+}
