@@ -14,8 +14,18 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+
 package org.apache.doris.flink.tools.cdc;
 
+import org.apache.flink.configuration.Configuration;
+import org.apache.flink.streaming.api.datastream.DataStream;
+import org.apache.flink.streaming.api.datastream.DataStreamSource;
+import org.apache.flink.streaming.api.datastream.SingleOutputStreamOperator;
+import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
+import org.apache.flink.util.OutputTag;
+import org.apache.flink.util.Preconditions;
+import org.apache.flink.util.StringUtils;
+
 import org.apache.doris.flink.catalog.doris.DorisSystem;
 import org.apache.doris.flink.catalog.doris.TableSchema;
 import org.apache.doris.flink.cfg.DorisConnectionOptions;
@@ -25,14 +35,6 @@ import org.apache.doris.flink.cfg.DorisReadOptions;
 import org.apache.doris.flink.sink.DorisSink;
 import org.apache.doris.flink.sink.writer.serializer.JsonDebeziumSchemaSerializer;
 import org.apache.doris.flink.table.DorisConfigOptions;
-import org.apache.flink.configuration.Configuration;
-import org.apache.flink.streaming.api.datastream.DataStream;
-import org.apache.flink.streaming.api.datastream.DataStreamSource;
-import org.apache.flink.streaming.api.datastream.SingleOutputStreamOperator;
-import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
-import org.apache.flink.util.OutputTag;
-import org.apache.flink.util.Preconditions;
-import org.apache.flink.util.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -84,9 +86,7 @@ public abstract class DatabaseSync {
 
     public abstract DataStreamSource<String> buildCdcSource(StreamExecutionEnvironment env);
 
-    /**
-     * Get the prefix of a specific tableList, for example, mysql is database, oracle is schema
-     */
+    /** Get the prefix of a specific tableList, for example, mysql is database, oracle is schema. */
     public abstract String getTableListPrefix();
 
     public DatabaseSync() throws SQLException {
@@ -96,10 +96,10 @@ public abstract class DatabaseSync {
     public void create() {
         this.includingPattern = includingTables == null ? null : Pattern.compile(includingTables);
         this.excludingPattern = excludingTables == null ? null : Pattern.compile(excludingTables);
-        this.multiToOneRulesPattern = multiToOneRulesParser(multiToOneOrigin,multiToOneTarget);
-        this.converter = new TableNameConverter(tablePrefix, tableSuffix,multiToOneRulesPattern);
-        //default enable light schema change
-        if(!this.tableConfig.containsKey(LIGHT_SCHEMA_CHANGE)){
+        this.multiToOneRulesPattern = multiToOneRulesParser(multiToOneOrigin, multiToOneTarget);
+        this.converter = new TableNameConverter(tablePrefix, tableSuffix, multiToOneRulesPattern);
+        // default enable light schema change
+        if (!this.tableConfig.containsKey(LIGHT_SCHEMA_CHANGE)) {
             this.tableConfig.put(LIGHT_SCHEMA_CHANGE, "true");
         }
     }
@@ -121,34 +121,43 @@ public abstract class DatabaseSync {
             syncTables.add(schema.getTableName());
             String dorisTable = converter.convert(schema.getTableName());
 
-            //Calculate the mapping relationship between upstream and downstream tables
-            tableMapping.put(schema.getTableIdentifier(), String.format("%s.%s", database, dorisTable));
+            // Calculate the mapping relationship between upstream and downstream tables
+            tableMapping.put(
+                    schema.getTableIdentifier(), String.format("%s.%s", database, dorisTable));
             if (!dorisSystem.tableExists(database, dorisTable)) {
                 TableSchema dorisSchema = schema.convertTableSchema(tableConfig);
-                //set doris target database
+                // set doris target database
                 dorisSchema.setDatabase(database);
                 dorisSchema.setTable(dorisTable);
                 dorisSystem.createTable(dorisSchema);
             }
-            if(!dorisTables.contains(dorisTable)){
+            if (!dorisTables.contains(dorisTable)) {
                 dorisTables.add(dorisTable);
             }
         }
-        if(createTableOnly){
+        if (createTableOnly) {
             System.out.println("Create table finished.");
             System.exit(0);
         }
         config.setString(TABLE_NAME_OPTIONS, getSyncTableList(syncTables));
         DataStreamSource<String> streamSource = buildCdcSource(env);
-        if(singleSink){
+        if (singleSink) {
             streamSource.sinkTo(buildDorisSink());
-        }else{
-            SingleOutputStreamOperator<Void> parsedStream = streamSource.process(new ParsingProcessFunction(converter));
+        } else {
+            SingleOutputStreamOperator<Void> parsedStream =
+                    streamSource.process(new ParsingProcessFunction(converter));
             for (String table : dorisTables) {
-                OutputTag<String> recordOutputTag = ParsingProcessFunction.createRecordOutputTag(table);
+                OutputTag<String> recordOutputTag =
+                        ParsingProcessFunction.createRecordOutputTag(table);
                 DataStream<String> sideOutput = parsedStream.getSideOutput(recordOutputTag);
-                int sinkParallel = sinkConfig.getInteger(DorisConfigOptions.SINK_PARALLELISM, sideOutput.getParallelism());
-                sideOutput.sinkTo(buildDorisSink(table)).setParallelism(sinkParallel).name(table).uid(table);
+                int sinkParallel =
+                        sinkConfig.getInteger(
+                                DorisConfigOptions.SINK_PARALLELISM, sideOutput.getParallelism());
+                sideOutput
+                        .sinkTo(buildDorisSink(table))
+                        .setParallelism(sinkParallel)
+                        .name(table)
+                        .uid(table);
             }
         }
     }
@@ -162,25 +171,22 @@ public abstract class DatabaseSync {
         Preconditions.checkNotNull(fenodes, "fenodes is empty in sink-conf");
         Preconditions.checkNotNull(user, "username is empty in sink-conf");
         Preconditions.checkNotNull(jdbcUrl, "jdbcurl is empty in sink-conf");
-        DorisConnectionOptions.DorisConnectionOptionsBuilder builder = new DorisConnectionOptions.DorisConnectionOptionsBuilder()
-                .withFenodes(fenodes)
-                .withBenodes(benodes)
-                .withUsername(user)
-                .withPassword(passwd)
-                .withJdbcUrl(jdbcUrl);
+        DorisConnectionOptions.DorisConnectionOptionsBuilder builder =
+                new DorisConnectionOptions.DorisConnectionOptionsBuilder()
+                        .withFenodes(fenodes)
+                        .withBenodes(benodes)
+                        .withUsername(user)
+                        .withPassword(passwd)
+                        .withJdbcUrl(jdbcUrl);
         return builder.build();
     }
 
-    /**
-     * create doris sink for multi table
-     */
-    public DorisSink<String> buildDorisSink(){
+    /** create doris sink for multi table. */
+    public DorisSink<String> buildDorisSink() {
         return buildDorisSink(null);
     }
 
-    /**
-     * create doris sink
-     */
+    /** create doris sink. */
     public DorisSink<String> buildDorisSink(String table) {
         String fenodes = sinkConfig.getString(DorisConfigOptions.FENODES);
         String benodes = sinkConfig.getString(DorisConfigOptions.BENODES);
@@ -189,69 +195,92 @@ public abstract class DatabaseSync {
 
         DorisSink.Builder<String> builder = DorisSink.builder();
         DorisOptions.Builder dorisBuilder = DorisOptions.builder();
-        dorisBuilder.setFenodes(fenodes)
-                .setBenodes(benodes)
-                .setUsername(user)
-                .setPassword(passwd);
-        sinkConfig.getOptional(DorisConfigOptions.AUTO_REDIRECT).ifPresent(dorisBuilder::setAutoRedirect);
+        dorisBuilder.setFenodes(fenodes).setBenodes(benodes).setUsername(user).setPassword(passwd);
+        sinkConfig
+                .getOptional(DorisConfigOptions.AUTO_REDIRECT)
+                .ifPresent(dorisBuilder::setAutoRedirect);
 
-        //single sink not need table identifier
-        if(!singleSink && !StringUtils.isNullOrWhitespaceOnly(table)){
+        // single sink not need table identifier
+        if (!singleSink && !StringUtils.isNullOrWhitespaceOnly(table)) {
             dorisBuilder.setTableIdentifier(database + "." + table);
         }
 
         Properties pro = new Properties();
-        //default json data format
+        // default json data format
         pro.setProperty("format", "json");
         pro.setProperty("read_json_by_line", "true");
-        //customer stream load properties
+        // customer stream load properties
         Properties streamLoadProp = DorisConfigOptions.getStreamLoadProp(sinkConfig.toMap());
         pro.putAll(streamLoadProp);
-        DorisExecutionOptions.Builder executionBuilder = DorisExecutionOptions.builder()
-                .setStreamLoadProp(pro);
+        DorisExecutionOptions.Builder executionBuilder =
+                DorisExecutionOptions.builder().setStreamLoadProp(pro);
 
-        sinkConfig.getOptional(DorisConfigOptions.SINK_LABEL_PREFIX).ifPresent(executionBuilder::setLabelPrefix);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_ENABLE_DELETE).ifPresent(executionBuilder::setDeletable);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_BUFFER_COUNT).ifPresent(executionBuilder::setBufferCount);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_BUFFER_SIZE).ifPresent(executionBuilder::setBufferSize);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_CHECK_INTERVAL).ifPresent(executionBuilder::setCheckInterval);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_MAX_RETRIES).ifPresent(executionBuilder::setMaxRetries);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_IGNORE_UPDATE_BEFORE).ifPresent(executionBuilder::setIgnoreUpdateBefore);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_LABEL_PREFIX)
+                .ifPresent(executionBuilder::setLabelPrefix);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_ENABLE_DELETE)
+                .ifPresent(executionBuilder::setDeletable);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_BUFFER_COUNT)
+                .ifPresent(executionBuilder::setBufferCount);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_BUFFER_SIZE)
+                .ifPresent(executionBuilder::setBufferSize);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_CHECK_INTERVAL)
+                .ifPresent(executionBuilder::setCheckInterval);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_MAX_RETRIES)
+                .ifPresent(executionBuilder::setMaxRetries);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_IGNORE_UPDATE_BEFORE)
+                .ifPresent(executionBuilder::setIgnoreUpdateBefore);
 
-
-        if(!sinkConfig.getBoolean(DorisConfigOptions.SINK_ENABLE_2PC)){
+        if (!sinkConfig.getBoolean(DorisConfigOptions.SINK_ENABLE_2PC)) {
             executionBuilder.disable2PC();
-        } else if(sinkConfig.getOptional(DorisConfigOptions.SINK_ENABLE_2PC).isPresent()){
-            //force open 2pc
+        } else if (sinkConfig.getOptional(DorisConfigOptions.SINK_ENABLE_2PC).isPresent()) {
+            // force open 2pc
             executionBuilder.enable2PC();
         }
 
-        sinkConfig.getOptional(DorisConfigOptions.SINK_ENABLE_BATCH_MODE).ifPresent(executionBuilder::setBatchMode);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_FLUSH_QUEUE_SIZE).ifPresent(executionBuilder::setFlushQueueSize);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_MAX_ROWS).ifPresent(executionBuilder::setBufferFlushMaxRows);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_MAX_BYTES).ifPresent(executionBuilder::setBufferFlushMaxBytes);
-        sinkConfig.getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_INTERVAL).ifPresent(v-> executionBuilder.setBufferFlushIntervalMs(v.toMillis()));
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_ENABLE_BATCH_MODE)
+                .ifPresent(executionBuilder::setBatchMode);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_FLUSH_QUEUE_SIZE)
+                .ifPresent(executionBuilder::setFlushQueueSize);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_MAX_ROWS)
+                .ifPresent(executionBuilder::setBufferFlushMaxRows);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_MAX_BYTES)
+                .ifPresent(executionBuilder::setBufferFlushMaxBytes);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_INTERVAL)
+                .ifPresent(v -> executionBuilder.setBufferFlushIntervalMs(v.toMillis()));
 
-        sinkConfig.getOptional(DorisConfigOptions.SINK_USE_CACHE).ifPresent(executionBuilder::setUseCache);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_USE_CACHE)
+                .ifPresent(executionBuilder::setUseCache);
 
         DorisExecutionOptions executionOptions = executionBuilder.build();
         builder.setDorisReadOptions(DorisReadOptions.builder().build())
                 .setDorisExecutionOptions(executionOptions)
-                .setSerializer(JsonDebeziumSchemaSerializer.builder()
-                        .setDorisOptions(dorisBuilder.build())
-                        .setNewSchemaChange(newSchemaChange)
-                        .setExecutionOptions(executionOptions)
-                        .setTableMapping(tableMapping)
-                        .setTableProperties(tableConfig)
-                        .setTargetDatabase(database)
-                        .build())
+                .setSerializer(
+                        JsonDebeziumSchemaSerializer.builder()
+                                .setDorisOptions(dorisBuilder.build())
+                                .setNewSchemaChange(newSchemaChange)
+                                .setExecutionOptions(executionOptions)
+                                .setTableMapping(tableMapping)
+                                .setTableProperties(tableConfig)
+                                .setTargetDatabase(database)
+                                .build())
                 .setDorisOptions(dorisBuilder.build());
         return builder.build();
     }
 
-    /**
-     * Filter table that need to be synchronized
-     */
+    /** Filter table that need to be synchronized. */
     protected boolean isSyncNeeded(String tableName) {
         boolean sync = true;
         if (includingPattern != null) {
@@ -264,40 +293,43 @@ public abstract class DatabaseSync {
         return sync;
     }
 
-    protected String getSyncTableList(List<String> syncTables){
-        if(!singleSink){
+    protected String getSyncTableList(List<String> syncTables) {
+        if (!singleSink) {
             return syncTables.stream()
-                    .map(v-> getTableListPrefix() + "\\." + v)
+                    .map(v -> getTableListPrefix() + "\\." + v)
                     .collect(Collectors.joining("|"));
-        }else{
+        } else {
             // includingTablePattern and ^excludingPattern
-            String includingPattern = String.format("(%s)\\.(%s)", getTableListPrefix(), includingTables);
+            String includingPattern =
+                    String.format("(%s)\\.(%s)", getTableListPrefix(), includingTables);
             if (StringUtils.isNullOrWhitespaceOnly(excludingTables)) {
                 return includingPattern;
-            }else{
-                String excludingPattern = String.format("?!(%s\\.(%s))$", getTableListPrefix(), excludingTables);
+            } else {
+                String excludingPattern =
+                        String.format("?!(%s\\.(%s))$", getTableListPrefix(), excludingTables);
                 return String.format("(%s)(%s)", includingPattern, excludingPattern);
             }
         }
     }
 
-    /**
-     * Filter table that many tables merge to one
-     */
-    protected HashMap<Pattern,String> multiToOneRulesParser(String multiToOneOrigin,String multiToOneTarget){
-        if(StringUtils.isNullOrWhitespaceOnly(multiToOneOrigin) || StringUtils.isNullOrWhitespaceOnly(multiToOneTarget)){
+    /** Filter table that many tables merge to one. */
+    protected HashMap<Pattern, String> multiToOneRulesParser(
+            String multiToOneOrigin, String multiToOneTarget) {
+        if (StringUtils.isNullOrWhitespaceOnly(multiToOneOrigin)
+                || StringUtils.isNullOrWhitespaceOnly(multiToOneTarget)) {
             return null;
         }
-        HashMap<Pattern,String> multiToOneRulesPattern= new HashMap<>();
+        HashMap<Pattern, String> multiToOneRulesPattern = new HashMap<>();
         String[] origins = multiToOneOrigin.split("\\|");
         String[] targets = multiToOneTarget.split("\\|");
-        if(origins.length!=targets.length){
-            System.out.println("param error : multi to one params length are not equal,please check your params.");
+        if (origins.length != targets.length) {
+            System.out.println(
+                    "param error : multi to one params length are not equal,please check your params.");
             System.exit(1);
         }
         try {
             for (int i = 0; i < origins.length; i++) {
-                multiToOneRulesPattern.put(Pattern.compile(origins[i]),targets[i]);
+                multiToOneRulesPattern.put(Pattern.compile(origins[i]), targets[i]);
             }
         } catch (Exception e) {
             System.out.println("param error : Your regular expression is incorrect,please check.");
@@ -306,7 +338,6 @@ public abstract class DatabaseSync {
         return multiToOneRulesPattern;
     }
 
-
     public DatabaseSync setEnv(StreamExecutionEnvironment env) {
         this.env = env;
         return this;
@@ -386,10 +417,10 @@ public abstract class DatabaseSync {
         private static final long serialVersionUID = 1L;
         private final String prefix;
         private final String suffix;
-        private Map<Pattern,String> multiToOneRulesPattern;
+        private Map<Pattern, String> multiToOneRulesPattern;
 
-        TableNameConverter(){
-            this("","");
+        TableNameConverter() {
+            this("", "");
         }
 
         TableNameConverter(String prefix, String suffix) {
@@ -397,35 +428,35 @@ public abstract class DatabaseSync {
             this.suffix = suffix == null ? "" : suffix;
         }
 
-        TableNameConverter(String prefix, String suffix,Map<Pattern, String> multiToOneRulesPattern) {
+        TableNameConverter(
+                String prefix, String suffix, Map<Pattern, String> multiToOneRulesPattern) {
             this.prefix = prefix == null ? "" : prefix;
             this.suffix = suffix == null ? "" : suffix;
             this.multiToOneRulesPattern = multiToOneRulesPattern;
         }
 
         public String convert(String tableName) {
-            if(multiToOneRulesPattern==null){
+            if (multiToOneRulesPattern == null) {
                 return prefix + tableName + suffix;
             }
 
-            String target=null;
+            String target = null;
 
-            for (Map.Entry<Pattern, String> patternStringEntry : multiToOneRulesPattern.entrySet()) {
-                if(patternStringEntry.getKey().matcher(tableName).matches()){
-                    target=patternStringEntry.getValue();
+            for (Map.Entry<Pattern, String> patternStringEntry :
+                    multiToOneRulesPattern.entrySet()) {
+                if (patternStringEntry.getKey().matcher(tableName).matches()) {
+                    target = patternStringEntry.getValue();
                 }
             }
             /**
-             * If multiToOneRulesPattern is not null and target is not assigned,
-             * then the synchronization task contains both multi to one and one to one ,
-             * prefixes and suffixes are added to common one-to-one mapping tables
-             * */
-            if(target==null){
+             * If multiToOneRulesPattern is not null and target is not assigned, then the
+             * synchronization task contains both multi to one and one to one , prefixes and
+             * suffixes are added to common one-to-one mapping tables
+             */
+            if (target == null) {
                 return prefix + tableName + suffix;
             }
             return target;
         }
     }
-
-
 }
